@@ -16,7 +16,7 @@ fi
 if ! grep -q "/bin/ksh" etc/shells ; then
    echo "/bin/ksh" >> etc/shells
 fi
-( cd usr/man/man1 ; rm -rf rksh.1.gz.gz )
-( cd usr/man/man1 ; ln -sf ksh.1.gz.gz rksh.1.gz.gz )
 ( cd bin ; rm -rf rksh )
 ( cd bin ; ln -sf ksh rksh )
+( cd usr/man/man1 ; rm -rf rksh.1.gz )
+( cd usr/man/man1 ; ln -sf ksh.1.gz rksh.1.gz )
